@@ -31,7 +31,7 @@ Usage Example::
 '''
 
 __author__ = "Michael Lustfield"
-__version__ = '0.1.4'
+__version__ = '0.2.0'
 __license__ = 'MIT'
 
 ### CUT HERE (see setup.py)
@@ -39,7 +39,15 @@ __license__ = 'MIT'
 import inspect
 import MySQLdb
 import MySQLdb.cursors as cursors
-from bottle import HTTPResponse, HTTPError
+import bottle
+
+
+# PluginError is defined to bottle >= 0.10
+if not hasattr(bottle, 'PluginError'):
+    class PluginError(bottle.BottleException):
+        pass
+
+    bottle.PluginError = PluginError
 
 
 class MySQLPlugin(object):
@@ -51,8 +59,10 @@ class MySQLPlugin(object):
     '''
 
     name = 'mysql'
+    api = 2
 
-    def __init__(self, dbuser=None, dbpass=None, dbname=None, dbhost='localhost', dbport=3306, autocommit=True, dictrows=True, keyword='db', charset='utf8', timezone=None):
+    def __init__(self, dbuser=None, dbpass=None, dbname=None, dbhost='localhost', dbport=3306, autocommit=True,
+                 dictrows=True, keyword='db', charset='utf8', timezone=None):
         self.dbhost = dbhost
         self.dbport = dbport
         self.dbuser = dbuser
@@ -73,25 +83,40 @@ class MySQLPlugin(object):
                 continue
             if other.keyword == self.keyword:
                 raise PluginError("Found another mysql plugin with conflicting settings (non-unique keyword).")
+            elif other.name == self.name:
+                self.name += '_%s' % self.keyword
+
+    def apply(self, callback, route):
+        # hack to support bottle v0.9.x
+        if bottle.__version__.startswith('0.9'):
+            config = route['config']
+            _callback = route['callback']
+        else:
+            config = route.config
+            _callback = route.callback
 
-    def apply(self, callback, context):
         # Override global configuration with route-specific values.
-        conf = context['config'].get('mysql') or {}
-        dbhost = conf.get('dbhost', self.dbhost)
-        dbport = conf.get('dbport', self.dbport)
-        dbuser = conf.get('dbuser', self.dbuser)
-        dbpass = conf.get('dbpass', self.dbpass)
-        dbname = conf.get('dbname', self.dbname)
-        autocommit = conf.get('autocommit', self.autocommit)
-        dictrows = conf.get('dictrows', self.dictrows)
-        keyword = conf.get('keyword', self.keyword)
-        charset = conf.get('charset', self.charset)
-        timezone = conf.get('timezone', self.timezone)
+        if "mysql" in config:
+            # support for configuration before `ConfigDict` namespaces
+            g = lambda key, default: config.get('mysql', {}).get(key, default)
+        else:
+            g = lambda key, default: config.get('mysql.' + key, default)
+
+        dbhost = g('dbhost', self.dbhost)
+        dbport = g('dbport', self.dbport)
+        dbuser = g('dbuser', self.dbuser)
+        dbpass = g('dbpass', self.dbpass)
+        dbname = g('dbname', self.dbname)
+        autocommit = g('autocommit', self.autocommit)
+        dictrows = g('dictrows', self.dictrows)
+        keyword = g('keyword', self.keyword)
+        charset = g('charset', self.charset)
+        timezone = g('timezone', self.timezone)
 
         # Test if the original callback accepts a 'db' keyword.
         # Ignore it if it does not need a database handle.
-        args = inspect.getargspec(context['callback'])[0]
-        if keyword not in args:
+        _args = inspect.getargspec(_callback)
+        if keyword not in _args.args:
             return callback
 
         def wrapper(*args, **kwargs):
@@ -100,14 +125,15 @@ class MySQLPlugin(object):
             try:
                 # Using DictCursor lets us return result as a dictionary instead of the default list
                 if dictrows:
-                    con = MySQLdb.connect(dbhost, dbuser, dbpass, dbname, dbport, cursorclass=cursors.DictCursor, charset=charset, use_unicode=True);
+                    con = MySQLdb.connect(dbhost, dbuser, dbpass, dbname, dbport, cursorclass=cursors.DictCursor,
+                                          charset=charset, use_unicode=True)
                 else:
-                    con = MySQLdb.connect(dbhost, dbuser, dbpass, dbname, dbport, charset=charset);
+                    con = MySQLdb.connect(dbhost, dbuser, dbpass, dbname, dbport, charset=charset)
                 cur = con.cursor()
                 if timezone:
-                    cur.execute("set time_zone=%s", (timezone, ));
-            except HTTPResponse, e:
-                raise HTTPError(500, "Database Error", e)
+                    cur.execute("set time_zone=%s", (timezone, ))
+            except bottle.HTTPResponse, e:
+                raise bottle.HTTPError(500, "Database Error", e)
 
             # Add the connection handle as a keyword argument.
             kwargs[keyword] = cur
@@ -118,10 +144,10 @@ class MySQLPlugin(object):
                     con.commit()
             except MySQLdb.IntegrityError, e:
                 con.rollback()
-                raise HTTPError(500, "Database Error", e)
-            except HTTPError, e:
+                raise bottle.HTTPError(500, "Database Error", e)
+            except bottle.HTTPError, e:
                 raise
-            except HTTPResponse, e:
+            except bottle.HTTPResponse, e:
                 if autocommit:
                     con.commit()
                 raise
@@ -133,4 +159,5 @@ class MySQLPlugin(object):
         # Replace the route callback with the wrapped one.
         return wrapper
 
+
 Plugin = MySQLPlugin
